import bpy
import datetime


def set_text_based_on_time_format(obj):
    """
    Update the text object's content based on the time format defined
    in its custom properties.
    """
    now = datetime.datetime.now()

    # Check if the object has the 'time_format' property
    if "time_format" in obj:
        time_format = obj["time_format"]
        
        # Set the object's text according to the specified date format
        obj.data.body = now.strftime(time_format)


def update_driver(scene):
    """
    Update all text objects in the scene at the start of each second
    based on their defined time format.
    """
    frame_rate = scene.render.fps
    current_frame = scene.frame_current

    # Check if the current frame is a multiple of the frame rate (start of a new second)
    if current_frame % frame_rate == 0:
        for obj in bpy.context.scene.objects:
            if obj.type == 'FONT':
                set_text_based_on_time_format(obj)


# Ensure the handler is not registered multiple times
if update_driver in bpy.app.handlers.frame_change_pre:
    bpy.app.handlers.frame_change_pre.remove(update_driver)

# Register the driver update function to run before each frame change
if update_driver not in bpy.app.handlers.frame_change_pre:
    bpy.app.handlers.frame_change_pre.append(update_driver)

print("Ready.")
